#
# spec file for package kubetui
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kubetui
Version:        1.7.1
Release:        1.0.2.1.sr20250601
Summary:        A terminal UI for Kubernetes
License:        MIT
URL:            https://github.com/sarub0b0/kubetui
Source0:        kubetui-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo >= 1.82
BuildRequires:  cargo-packaging
BuildRequires:  zstd

%description

Kubetui is a terminal user interface (TUI) tool designed for monitoring
Kubernetes resources.  It provides an easy-to-use interface for developers and
operators to access important information about their applications and
infrastructure.

%prep
%autosetup -a1

%build
%{cargo_build}

%install
%{cargo_install}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%changelog
* Sat May 10 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.7.1:
  * Fixes
  - Zsh completion: Add autoload -Uz is-at-least to fix
    '_kubetui:3:' command not found: is-at-least error #767
  * Dependency Updates
  - clap: Updated to v4.5.35 → v4.5.36 → v4.5.37
    [#753], #759, #762 by @renovate
  - flate2: Updated to v1.1.1
    [#754] by @renovate
  - arboard: Updated to v3.5.0
    [#755] by @renovate
  - ctrlc: Updated to v3.4.6
    [#756] by @renovate
  - tokio: Updated to v1.44.2 → v1.45.0
    [#757], #764 by @renovate
  - anyhow: Updated to v1.0.98
    [#760] by @renovate
  - chrono: Updated to v0.4.41
    [#763] by @renovate
  * Maintenance
  - Lock file maintenance
    [#758], #761, #765 by @renovate
* Thu Apr 17 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- relax version constraint on cargo to allow versions equal to or
  newer than 1.82
* Sat Mar 29 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.7.0:
  * New Features
  - Added shell completion support for bash and zsh (#745)
  * Major Updates
  - Upgraded rust crate dirs to v6 (#696)
  - Upgraded rust crate nom to v8 (#704)
  * Other Updates
  - Updated rust crate kube to 0.99.0 (#740)
  - Updated rust crate http to v1.3.0 and v1.3.1 (#737)
  - Updated rust crate tokio to v1.44.1 (#741)
  - Updated rust crate once_cell to v1.21.1, v1.21.2, v1.21.3
    (#742, #752)
  - Updated rust crate async-trait to v0.1.88 (#744)
  - Updated rust crate log to v0.4.27 (#747)
  - Updated rust crate clap to v4.5.33, v4.5.34 (#748)
  - Routine dependency lock file maintenance (#743, #746, #751)
* Tue Mar 11 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.6.2:
  * feat: bump version to 1.6.2
  * fix(app): propagate shutdown reason (#736)
* Tue Mar 11 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.6.1:
  * feat: bump version to 1.6.1
  * fix(deps): update rust crate clap to v4.5.32 (#735)
  * chore: update Kind version to latest in Makefile
  * fix(deps): update rust crate once_cell to v1.21.0 (#734)
  * fix: Improve thread management to prevent unwanted terminal
    output on exit (#732)
  * fix(deps): update rust crate serde to v1.0.219 (#733)
  * fix(deps): update rust crate tokio to v1.44.0 (#731)
  * fix(deps): update rust crate bytes to v1.10.1 (#730)
  * fix(deps): update rust crate indoc to v2.0.6 (#729)
  * fix(deps): update rust crate thiserror to v2.0.12 (#728)
  * fix(deps): update rust crate serde_json to v1.0.140 (#727)
  * fix(deps): update rust crate async-trait to v0.1.87 (#726)
  * fix(deps): update rust crate anyhow to v1.0.97 (#725)
  * chore(deps): update rust crate rstest to 0.25.0 (#724)
  * fix(deps): update rust crate bitflags to v2.9.0 (#723)
  * chore(deps): lock file maintenance (#722)
  * fix(deps): update rust crate chrono to v0.4.40 (#721)
  * feat: improve error handling and add new tests
  * fix(deps): update rust crate clap to v4.5.31 (#720)
  * fix(deps): update rust crate flate2 to v1.1.0 (#719)
  * fix(deps): update rust crate log to v0.4.26 (#718)
  * fix(deps): update rust crate serde_json to v1.0.139 (#717)
  * fix(deps): update rust crate serde to v1.0.218 (#716)
  * fix(deps): update rust crate anyhow to v1.0.96 (#715)
  * fix(deps): update rust crate clap to v4.5.30 (#714)
  * fix(deps): update rust crate strum to v0.27.1 (#713)
  * fix(deps): update rust crate clap to v4.5.29 (#711)
  * fix(deps): update rust crate strum to 0.27.0 (#710)
  * fix(deps): update rust crate once_cell to v1.20.3 (#709)
  * fix(deps): update rust crate clap to v4.5.28 (#708)
  * fix(deps): update rust crate bytes to v1.10.0 (#707)
  * fix(deps): update rust crate async-trait to v0.1.86 (#706)
  * fix(deps): update rust crate serde_json to v1.0.138 (#705)
  * chore(deps): lock file maintenance (#703)
  * fix(deps): update rust crate clap to v4.5.27 (#702)
  * fix(deps): update rust crate serde_json to v1.0.137 (#701)
  * fix(deps): update rust crate serde_json to v1.0.136 (#700)
  * chore(deps): lock file maintenance (#699)
  * fix(deps): update rust crate bitflags to v2.8.0 (#698)
  * fix(deps): update rust crate log to v0.4.25 (#697)
  * chore(deps): remove unused regex-syntax dependency
  * fix(deps): update rust crate log to v0.4.24 (#695)
  * fix(deps): update rust crate thiserror to v2.0.11 (#694)
  * fix(deps): update rust crate bitflags to v2.7.0 (#693)
  * fix(deps): update rust crate clap to v4.5.26 (#692)
  * fix(deps): update rust crate clap to v4.5.25 (#691)
  * fix(deps): update rust crate tokio to v1.43.0 (#689)
  * fix(deps): update rust crate thiserror to v2.0.10 (#690)
  * fix(deps): update rust crate clap to v4.5.24 (#688)
  * fix(deps): update rust crate async-trait to v0.1.85 (#686)
  * docs: mark UI appearance customization as beta
  * fix(deps): update rust crate serde_json to v1.0.135 (#687)
  * chore: add cspell.json to exclude list in Cargo.toml
* Tue Jan  7 2025 opensuse_buildservice@ojkastl.de
- refactor "_service" file to not have both tarball and
  obscpio archive
- Update to version 1.6.0:
  * feat: bump version to 1.6.0
  * refactor: remove debug statements from code
  * docs: update help command output
  * docs: add customizable UI appearance with config file
  * refactor(theme): rename selection to selected_item
  * chore(example): enhance theme settings and translations
  * feat(config): replace xdg crate with dirs crate
  * feat(theme): add YAML and API dialog theme support
  * feat(api_resources): add API theme configuration support
  * feat(api_resources): add styled table for kube resources
  * feat(event): add event highlight configuration
  * feat(pod): add default pod highlight rules
  * fix(theme): improve regex error handling
  * feat(theme): enable custom pod table highlights
  * refactor(poller): remove PollerBase struct
  * feat(theme): add table header theme configuration
  * feat(theme): add input form theme configuration
  * feat(theme): apply theme to remaining widgets
  * feat(theme): add theme support for multiple select widget
  * feat(theme): add theme support for select widget
  * feat: add help dialog theme configuration support
  * feat: add style_to_ansi function to convert Style to ANSI
  * feat(theme): add dialog theme configuration
  * feat(ui/dialog): update Dialog and StyledClear widget
  * feat(theme): add table filter form theme configuration
  * feat(theme): add text theme configuration for search and
    selection
  * feat(ui): add theming support to Text widget
  * feat(ui): add theming support to InputForm widget
  * feat(theme): add widget theme support
  * feat(theme): add header theme support
  * feat(config): add environment variable support
  * feat(theme): add support for custom tab theme configuration
  * feat(config): add configuration file loading
  * fix(ui): adjust tab padding and spacing
  * fix(deps): update rust crate async-trait to v0.1.84 (#685)
  * Add support for pretty-printed JSON logs (#674)
  * chore(deps): update rust crate rstest to 0.24.0 (#684)
  * feat(clipboard): copy to both primary and clipboard selections
    on linux (#683)
  * fix(deps): update rust crate serde to v1.0.217 (#682)
  * fix(deps): update kube-rs (kube, kube-runtime, k8s-openapi)
    (#679)
  * fix(deps): update rust crate anyhow to v1.0.95 (#681)
  * fix(deps): update rust crate thiserror to v2.0.9 (#678)
  * fix(deps): update rust crate serde_json to v1.0.134 (#677)
  * refactor: update lifetimes and impl blocks
  * fix(help): update title in help dialog
  * chore(cspell): update cspell.json word list
  * chore: rename 'Api' to 'API' in titles
  * chore(api_resources): rename list components to api
  * fix(deps): update rust crate thiserror to v2.0.8 (#675)
* Sun Dec 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.5.4:
  * Release version 1.5.4
  * feat(clipboard): update arboard features for wayland
  * chore(deps): update arboard to version 3.4.1
  * Revert "feat(clipboard): update arboard features for wayland"
  * feat(clipboard): remove clipboard from render
  * feat(clipboard): update arboard features for wayland
  * fix(deps): update rust crate thiserror to v2.0.7 (#672)
  * chore(deps): lock file maintenance (#671)
  * fix(deps): update rust crate serde to v1.0.216 (#670)
  * fix(deps): update rust crate chrono to v0.4.39 (#669)
  * fix(deps): update rust crate thiserror to v2.0.6 (#668)
  * fix(deps): update rust crate thiserror to v2.0.5 (#667)
  * fix(deps): update rust crate clap to v4.5.23 (#666)
  * chore(deps): update rust crate tokio to v1.42.0 (#662)
  * fix(deps): update rust crate http to v1.2.0 (#665)
  * fix(deps): update rust crate clap to v4.5.22 (#664)
  * fix(deps): update rust crate anyhow to v1.0.94 (#663)
  * fix(deps): update rust crate thiserror to v2.0.4 (#661)
  * chore(config): migrate config renovate.json
  * chore: Update renovate.json
  * fix(deps): update rust crate kube to 0.97.0 (#655)
  * fix(deps): update rust crate thiserror to v2
  * chore(deps): lock file maintenance (#658)
  * fix(deps): update rust crate bytes to v1.9.0 (#657)
  * feat(clipboard): integrate arboard for clipboard handling
  * chore(deps): lock file maintenance (#656)
  * chore(deps): update rust crate mockall to v0.13.1 (#654)
  * fix(deps): update rust crate serde_json to v1.0.133 (#653)
  * fix(deps): update rust crate flate2 to v1.0.35 (#651)
  * fix(deps): update rust crate clap to v4.5.21 (#650)
  * fix(deps): update rust crate serde to v1.0.215 (#649)
  * fix(deps): update rust crate thiserror to v1.0.69 (#648)
  * fix(deps): update all dependencies (#646)
  * fix(deps): update rust crate thiserror to v1.0.68
  * fix(deps): update rust crate thiserror to v1.0.67
  * fix(deps): update rust crate anyhow to v1.0.92
  * fix(deps): update rust crate thiserror to v1.0.66
  * chore(deps): lock file maintenance
  * fix(deps): update rust crate serde to v1.0.214
  * refactor(ui): update Table widget to use row_highlight_style
  * refactor(widget): remove unused chunk_index field
  * refactor(ui/single_select): remove unused chunk_index field
  * refactor(ui/table): remove unused show_status and chunk_index
  * fix(deps): update rust crate ratatui to 0.29.0
  * refactor: remove derivative crate and update impls
  * fix(deps): update rust crate bytes to v1.8.0
  * chore(deps): update rust crate tokio to v1.41.0
  * fix(deps): update rust crate regex to v1.11.1
  * fix(deps): update rust crate serde to v1.0.213
  * fix(deps): update all dependencies
  * chore(deps): update actions/checkout digest to 11bd719
  * fix(ui/single_select): Added a Default implementation for
    SelectForm using SelectFormBuilder
  * refactor(widget): modularize SelectForm and FilterForm for
    MultipleSelect
  * refactor(widget): move SingleSelectBuilder to top
  * refactor(widget): modularize SelectForm and SingleSelect
  * refactor: replace InputForm with FilterForm in SingleSelect
  * fix(deps): update rust crate serde_json to v1.0.132
  * fix(deps): update rust crate serde_json to v1.0.131
  * fix(deps): update rust crate serde_json to v1.0.130
  * fix(deps): update rust crate anyhow to v1.0.90
  * chore(deps): lock file maintenance
  * fix(deps): update rust crate serde_json to v1.0.129
  * fix(deps): update rust crate kube to 0.96.0
  * fix(deps): update rust crate clap to v4.5.20
  * chore(deps): update actions/checkout digest to eef6144
  * refactor(ui/input): add allow dead_code attribute to suffix method
  * refactor: remove unnecessary references in widget_base
  * fix(deps): update rust crate once_cell to v1.20.2
  * fix(deps): update rust crate futures to v0.3.31
  * refactor: rename popup to dialog in AppleScript files
  * refactor: rename popup to dialog in UI components
  * fix(deps): update rust crate clap to v4.5.19
  * fix(deps): update rust crate regex to v1.11.0
  * fix(deps): update rust crate once_cell to v1.20.1
  * fix(deps): update rust crate regex-syntax to v0.8.5
  * chore(deps): update rust crate rstest to 0.23.0
  * refactor(wrap): rename function and reduce nesting
  * refactor: rename spans module to line for clarity
  * refactor: rename generate_style_from_ansi_color to ansi_to_style
  * refactor(ui): add FilterForm with fixed height for Table widget
  * refactor(ui): add SearchForm with fixed height for Text widget
  * refactor(input): add allow(dead_code) attribute
  * refactor(widget): restructure and rename modules
  * refactor(widget): change module visibility and imports
  * refactor(config): rename WidgetConfig to WidgetBase
  * chore(deps): lock file maintenance
  * fix(deps): update rust crate flate2 to v1.0.34
  * fix(deps): update rust crate async-trait to v0.1.83
  * fix(deps): update rust crate thiserror to v1.0.64
  * fix(deps): update rust crate clap to v4.5.18
  * fix(deps): update rust crate unicode-width to 0.2.0
  * feat(ui): change ansi color reset sequence handling from
    Style::reset() to Style::default() in ansi_color.rs
  * fix(deps): update rust crate bytes to v1.7.2
  * fix(deps): update rust crate unicode-segmentation to v1.12.0
  * fix(deps): update kube-rs (kube, kube-runtime, k8s-openapi)
  * chore(deps): update rust crate tokio to v1.40.0
  * fix(deps): update rust crate serde to v1.0.210
  * fix(deps): update all dependencies
  * fix(deps): update rust crate kube to 0.94.0
  * refactor(ui): remove unused layout field from InputForm
  * refactor(ui): merge FilterForm and SearchForm into InputForm
  * refactor: replace deprecated methods and rename variables
  * fix(k8s): reset table header style using code `\x1b[39m`
  * fix(deps): update rust crate ratatui to v0.28.1
  * fix(deps): update rust crate flate2 to v1.0.33
  * fix(deps): update rust crate serde to v1.0.209
  * fix(deps): update rust crate serde_json to v1.0.127
  * chore(deps): lock file maintenance
  * fix(deps): update rust crate flate2 to v1.0.32
  * chore(deps): update rust crate tokio to v1.39.3
  * fix(deps): update rust crate clap to v4.5.16
  * chore(deps): lock file maintenance
  * fix(deps): update rust crate serde to v1.0.208
  * fix(deps): update rust crate serde_json to v1.0.125
  * fix(deps): update rust crate ctrlc to v3.4.5
  * fix(deps): update rust crate serde to v1.0.207
  * fix(deps): update rust crate serde_json to v1.0.124
  * fix(deps): update rust crate serde_json to v1.0.123
  * fix(deps): update rust crate serde to v1.0.206
  * fix(deps): update rust crate clap to v4.5.15
  * docs(readme): add installation for Arch Linux
  * fix(deps): update rust crate clap to v4.5.14
  * fix(deps): update rust crate serde to v1.0.205
  * fix(deps): update rust crate ratatui to 0.28.0
  * chore(deps): update rust crate rstest to 0.22.0
  * fix(deps): update rust crate flate2 to v1.0.31
  * fix(deps): update rust crate regex to v1.10.6
  * fix(deps): update all dependencies
  * fix(deps): update rust crate clap to v4.5.13
  * fix(deps): update rust crate clap to v4.5.12
  * fix(deps): update rust crate bytes to v1.7.0
  * fix(deps): update rust crate serde_json to v1.0.121
  * chore(deps): update rust crate tokio to v1.39.2
  * fix(deps): update rust crate clap to v4.5.11
  * chore(deps): update rust crate tokio to v1.39.1
  * fix(deps): update rust crate clap to v4.5.10
  * chore(script): Add script to toggle split direction in iTerm
  * fix(deps): update rust crate kube to v0.93.1
* Wed Jul 24 2024 ekr59uv25@gmail.com
- Update to version 1.5.3:
  * fix(deps): update rust crate kube to 0.93.0
  * chore(deps): update rust crate mockall to 0.13.0
  * chore(deps): lock file maintenance
  * fix(deps): update rust crate thiserror to v1.0.63
  * chore(deps): update rust crate tokio to v1.38.1
  * fix(deps): update rust crate bytes to v1.6.1
  * fix(deps): update rust crate thiserror to v1.0.62
  * fix(deps): update rust crate clap to v4.5.9
  * fix(deps): update rust crate async-trait to v0.1.81
  * docs: Add keybinding for toggling split layout direction
  * feat(ui): Add support for toggling split layout direction
  * fix(deps): update rust crate serde to v1.0.204
  * fix(deps): update rust crate serde_json to v1.0.120
  * fix(kube/log): prevent removal of leading spaces in container logs
  * fix(deps): update rust crate serde_json to v1.0.119
  * chore(render): add error logging in window action
  * refactor(kube/store): clippy needless borrow
  * refactor(kube/secret): replaced with the `?` operator
  * chore(ui): suppress warnings for unused code in widget.rs
  * chore(apis): allow dead code in kube apis module
  * refactor(related_resources): simplify related resource structs
  * refactor(v1_table): replace ToString with Display for Value
  * fix(deps): update rust crate clap to v4.5.8
  * fix(deps): update rust crate log to v0.4.22
  * chore(deps): lock file maintenance
  * fix(ui): Simplify generate_spans_line generation and tests
  * fix(ui): Update crossterm usage to ratatui's crossterm
  * fix(deps): update rust crate ratatui to 0.27.0
  * fix(deps): update rust crate serde_json to v1.0.118
  * fix(deps): update rust crate strum to v0.26.3
  * fix(deps): update rust crate kube to v0.92.1
  * chore(deps): lock file maintenance
  * chore(deps): update actions/checkout digest to 692973e
  * fix(deps): update rust crate kube to 0.92.0
  * fix(deps): update rust crate clap to v4.5.7
  * fix(deps): update all dependencies
  * chore(deps): lock file maintenance
  * fix(deps): update rust crate clap to v4.5.6
  * fix(deps): update rust crate clap to v4.5.5
  * fix(deps): update rust crate unicode-width to v0.1.13
  * test(network): fix kube network description tests
  * chore(deps): update rust crate rstest to 0.21.0
  * chore(deps): update rust crate tokio to v1.38.0
  * chore(deps): update rust crate rstest to 0.20.0
  * fix(deps): update rust crate serde to v1.0.203
  * chore(deps): lock file maintenance
  * fix(deps): update rust crate ratatui to v0.26.3
  * chore(deps): update actions/checkout digest to a5ac7e5
  * docs: add Chocolatey installation note
  * fix(deps): update rust crate anyhow to v1.0.86
  * fix(deps): update rust crate anyhow to v1.0.85
  * fix(deps): update rust crate thiserror to v1.0.61
* Thu May 16 2024 ekr59uv25@gmail.com
- Update to version 1.5.2:
  * (experimental) Support Gateway API (only Gateway and HTTPRoute)
  * fix(ui/table): ensure filter form displays when items are empty
* Wed Apr 24 2024 dcermak@suse.com
- Update to version 1.5.1:
  * Release version 1.5.1
  * Bump deps including rustls (fixes bsc#1223225 - CVE-2024-32650)
* Sun Jan 28 2024 Kosei Hashimoto <ekr59uv25@gmail.com>
- Initial spec for kubetui 1.5.0
